Upgrading Pyblosxom — Pyblosxom 1.5 documentation

### Navigation

- index
- modules |
- next |
- previous |
- Pyblosxom 1.5 documentation »

# Upgrading Pyblosxom

This walks through upgrading Pyblosxom from a previous version.

## Before upgrading

First, read through the What’s New documentation which includes pointers to users and plugin developers regarding changes between older versions and newer versions.

This is at What’s new in 1.5 (December 2011).

To be safe, install Pyblosxom locally (as opposed to on the server or over your existing blog) and test your blog configuration and plugins to make sure everything works with the new version.

## Upgrading site-wide

Using pip:

    pip install --upgrade pyblosxom

OR Using easy_install:

    easy_install -U pyblosxom

## Upgrading in a virtual environment

First, activate your virtual environment, then use either pip or easy_install as above.

### Navigation

- index
- modules |
- next |
- previous |
- Pyblosxom 1.5 documentation »